@@ -32,7 +32,7 @@ def auth_required(function):
             token = request.headers['token']
             user = User.query.filter_by(token=token).first()
             if user is not None:
-                return function(token, *args, **kwargs) if authorized(user, token) else "Auth failed, maybe you token is expired, try login again"
+                return function(token=token, *args, **kwargs) if authorized(user, token) else "Auth failed, maybe you token is expired, try login again"
         except Exception as e:
             return "Auth error: " + str(e)
     return decorated
